summaryrefslogtreecommitdiff
path: root/src/stringprep
diff options
context:
space:
mode:
authorMickaël Rémond <mickael.remond@process-one.net>2007-12-24 13:57:53 +0000
committerMickaël Rémond <mickael.remond@process-one.net>2007-12-24 13:57:53 +0000
commit22f928122f46136eb428efdac5f8d3cff4a2dcae (patch)
tree7a903401a33c8118cd8cd7ba1666b9a7f3215f13 /src/stringprep
parent* applied copyright patch 2. (diff)
* Applied copyright patch 3.
SVN Revision: 1113
Diffstat (limited to 'src/stringprep')
-rw-r--r--src/stringprep/stringprep.erl26
-rw-r--r--src/stringprep/stringprep_drv.c20
-rw-r--r--src/stringprep/stringprep_sup.erl21
3 files changed, 61 insertions, 6 deletions
diff --git a/src/stringprep/stringprep_drv.c b/src/stringprep/stringprep_drv.c
index a12ec9a8..c77e5195 100644
--- a/src/stringprep/stringprep_drv.c
+++ b/src/stringprep/stringprep_drv.c
@@ -1,4 +1,22 @@
-/* $Id$ */
+/*
+ * ejabberd, Copyright (C) 2002-2007 Process-one
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ */
#include <stdio.h>
#include <string.h>
diff --git a/src/stringprep/stringprep_sup.erl b/src/stringprep/stringprep_sup.erl
index e3b95796..483d0a3e 100644
--- a/src/stringprep/stringprep_sup.erl
+++ b/src/stringprep/stringprep_sup.erl
@@ -2,9 +2,28 @@
%%% File : stringprep_sup.erl
%%% Author : Mickael Remond <mremond@process-one.net>
%%% Description : Supervisor for the Stringprep worker.
-%%%
%%% Created : 29 Jun 2007 by Mickael Remond <mremond@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%-------------------------------------------------------------------
+
-module(stringprep_sup).
-behaviour(supervisor).
diff --git a/src/stringprep/stringprep.erl b/src/stringprep/stringprep.erl
index 50d82cd6..e0ec6e8a 100644
--- a/src/stringprep/stringprep.erl
+++ b/src/stringprep/stringprep.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : stringprep.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Interface to stringprep_drv
-%%% Created : 16 Feb 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 16 Feb 2003 by Alexey Shchepin <alexey@proces-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(stringprep).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : stringprep.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Interface to stringprep_drv